## Video player

A SNUB project can contain one or more video players. 
* The video player always shows the frame associated with the current time (see [timeline](timeline.md)). 
* If the current time is outside the interval of the video, the video player will show the first or last frame of the video. 
* It is possible zoom in on specific areas of a video frame using pan/zoom gestures.

### Playback

See [timeline](timeline.md) for how to control the current time and speed of video playback. If playback is not smooth, try minimizing or closing parts of the layout (see [layout](layout.md)).